@@ -120,7 +120,7 @@ TEST_I2C_ADDR = 0xab
 TEST_MOD_CMD_NAME = "TST"
 TEST_MOD_NAME = "Test"
 SUP_TYPE_TEST_DATA = list(repeat([t for t in DataType if t not in [DataType.Str, DataType.Hex16, DataType.Hex8]], 15))
-MOD_TYPE_TEST_DATA = list(repeat([t for t in DataType if t not in [DataType.Str, DataType.U8, DataType.U16]], 15))
+MOD_TYPE_TEST_DATA = list(repeat([t for t in DataType if t not in [DataType.Str, DataType.UINT8, DataType.UINT8]], 15))
 
 
 def test_request_telemetry_definition():
@@ -155,14 +155,14 @@ def test_request_module_definition():
 
 # Testing pumpkin_supmcu.supmcu.i2c module
 TEST_DATATYPE_VALUES = {
-    DataType.U8: 127,
-    DataType.U16: 1234,
-    DataType.U32: 123456,
-    DataType.U64: 12345678,
-    DataType.I8: -127,
-    DataType.I16: -1234,
-    DataType.I32: -123456,
-    DataType.I64: -12345678,
+    DataType.UINT8: 127,
+    DataType.UINT16: 1234,
+    DataType.UINT32: 123456,
+    DataType.UINT64: 12345678,
+    DataType.INT8: -127,
+    DataType.INT16: -1234,
+    DataType.INT32: -123456,
+    DataType.INT64: -12345678,
     DataType.Hex8: 127,
     DataType.Hex16: 1234,
     DataType.Float: 1.25,
